@@ -16,3 +16,8 @@ do
     fi
     usr/bin/gtk-update-icon-cache -f -q --ignore-theme-index usr/share/icons/$i
 done
+
+# Restart gconfd-2 if running to reload new gconf settings
+if ps acx | grep -q gconfd-2 ; then
+        killall -HUP gconfd-2 ;
+fi
